@@ -37,7 +37,7 @@
        Keith Owens <kaos@ocs.com.au> April 2000.
    */
 
-#ident "$Id: depmod.c 1.13 Thu, 20 Apr 2000 14:31:49 +1000 kaos $"
+#ident "$Id: depmod.c 1.15 Sun, 09 Jul 2000 14:19:11 +1000 kaos $"
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -219,7 +219,7 @@ static void resolve(void)
 			   newest first, so we want the last match in
 			   the chain.  In particular, this prefers
 			   kernel symbols to that of any module.
-			   
+
 			   If we are ignoring the genksyms suffix in this
 			   comparision then there are two hashes to try.
 			 */
@@ -260,7 +260,7 @@ static int loadobj(const char *objname, int ignore_suffix)
 {
 	static char *currdir;
 	static int currdir_len;
-	FILE *fp;
+	int fp;
 	MODULE *mod;
 	SYMBOL *undefs[5000];
 	SYMBOL *defsym[5000];
@@ -278,14 +278,14 @@ static int loadobj(const char *objname, int ignore_suffix)
 	p = strrchr(objname, '/');
 	len = 1 + (int)(p - objname);
 
-	if ((fp = fopen(objname, "r")) == NULL)
+ 	if ((fp = gzf_open(objname, O_RDONLY)) < 0)
 		return 1;
 
-	if (!(f = obj_load(fp, ET_REL))) {
-		fclose(fp);
+	if (!(f = obj_load(fp, ET_REL, objname))) {
+		gzf_close(fp);
 		return -1;
 	}
-	fclose(fp);
+	gzf_close(fp);
 
 	/*
 	 * If we have changed base directory
