@@ -24,7 +24,7 @@
 #ifndef MODUTILS_OBJ_H
 #define MODUTILS_OBJ_H 1
 
-#ident "$Id: obj.h 1.4 Tue, 18 Apr 2000 13:38:59 +1000 kaos $"
+#ident "$Id: obj.h 1.7 Sun, 09 Jul 2000 14:46:03 +1000 kaos $"
 
 /* The relocatable object is manipulated using elfin types.  */
 
@@ -105,6 +105,7 @@ struct obj_file
   unsigned long local_symtab_size;
   struct obj_symbol **local_symtab;
   struct obj_symbol *symtab[HASH_BUCKETS];
+  const char *filename;
 };
 
 enum obj_reloc
@@ -162,6 +163,7 @@ struct obj_symbol_patch_struct
 #define arch_create_got			ObjW(arch_create_got)
 #define arch_init_module		ObjW(arch_init_module)
 #define arch_load_proc_section		ObjW(arch_load_proc_section)
+#define arch_finalize_section_address	ObjW(arch_finalize_section_address)
 
 unsigned long obj_elf_hash (const char *);
 
@@ -213,7 +215,7 @@ unsigned long obj_load_size (struct obj_file *f);
 
 int obj_relocate (struct obj_file *f, ElfW(Addr) base);
 
-struct obj_file *obj_load (FILE *f, Elf32_Half e_type);
+struct obj_file *obj_load (int f, Elf32_Half e_type, const char *filename);
 
 void obj_free (struct obj_file *f);
 
@@ -240,6 +242,8 @@ int arch_create_got (struct obj_file *f);
 struct module;
 int arch_init_module (struct obj_file *f, struct module *);
 
-int arch_load_proc_section (struct obj_section *sec, FILE *fp);
+int arch_load_proc_section (struct obj_section *sec, int fp);
+
+int arch_finalize_section_address (struct obj_file *f, ElfW(Addr) base);
 
 #endif /* obj.h */
