@@ -48,7 +48,7 @@
        Keith Owens <kaos@ocs.com.au> April 2000.
    */
 
-#ident "$Id: insmod.c 1.17 Fri, 21 Apr 2000 13:50:20 +1000 kaos $"
+#ident "$Id: insmod.c 1.20 Sun, 09 Jul 2000 14:48:27 +1000 kaos $"
 
 #include <sys/types.h>
 #include <stdlib.h>
@@ -1046,9 +1046,8 @@ static int init_module(const char *m_name, struct obj_file *f,
 	ret = sys_init_module(m_name, (struct module *) image);
 	if (ret) {
 		error("init_module: %m");
-		if (errno == EBUSY)
-			lprintf("Hint: this error can be caused by incorrect module parameters, "
-				"including invalid IO or IRQ parameters");
+		lprintf("Hint: insmod errors can be caused by incorrect module parameters, "
+			"including invalid IO or IRQ parameters");
 	}
 
 	free(image);
@@ -1240,7 +1239,7 @@ int INSMOD_MAIN(int argc, char **argv)
 	int m_crcs;
 	char m_strversion[STRVERSIONLEN];
 	char *filename;
-	FILE *fp;
+	int fp;
 	struct obj_file *f;
 	struct obj_section *kallsyms = NULL;
 	int o;
@@ -1358,14 +1357,14 @@ int INSMOD_MAIN(int argc, char **argv)
 		printf("Using %s\n", filename);
 
 	/* And open it.  */
-	if ((fp = fopen(filename, "r")) == NULL) {
+	if ((fp = gzf_open(filename, O_RDONLY)) == -1) {
 		error_file = filename;
 		error("%s: %m", filename);
 		return 1;
 	}
 	/* Try to prevent multiple simultaneous loads.  */
 	if (dolock)
-		flock(fileno(fp), LOCK_EX);
+		flock(fp, LOCK_EX);
 
 	if (!get_kernel_info(K_SYMBOLS))
 		goto out;
@@ -1384,7 +1383,7 @@ int INSMOD_MAIN(int argc, char **argv)
 	}
 
 	error_file = filename;
-	if ((f = obj_load(fp, ET_REL)) == NULL)
+	if ((f = obj_load(fp, ET_REL, filename)) == NULL)
 		goto out;
 
 	/* Version correspondence?  */
@@ -1524,8 +1523,8 @@ int INSMOD_MAIN(int argc, char **argv)
 
       out:
 	if (dolock)
-		flock(fileno(fp), LOCK_UN);
-	fclose(fp);
+		flock(fp, LOCK_UN);
+	close(fp);
 	if (!noload)
 		snap_shot(NULL, 0);
 
