@@ -19,7 +19,7 @@
    along with this program; if not, write to the Free Software Foundation,
    Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
 
-#ident "$Id: obj_common.c 1.4 Thu, 20 Apr 2000 14:31:49 +1000 kaos $"
+#ident "$Id: obj_common.c 1.5 Sun, 09 Jul 2000 14:46:03 +1000 kaos $"
 
 #include <string.h>
 #include <assert.h>
@@ -241,6 +241,9 @@ obj_load_order_prio(struct obj_section *a)
   if (!(af & SHF_WRITE)) ac |= 8;
   if (af & SHF_EXECINSTR) ac |= 4;
   if (a->header.sh_type != SHT_NOBITS) ac |= 2;
+#if defined(ARCH_ia64)
+  if (af & SHF_IA_64_SHORT) ac -= 1;
+#endif
 
   return ac;
 }
