@@ -19,7 +19,7 @@
    along with this program; if not, write to the Free Software Foundation,
    Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
 
-#ident "$Id: obj_reloc.c 1.5 Thu, 13 Apr 2000 18:17:59 +1000 kaos $"
+#ident "$Id: obj_reloc.c 1.6 Sun, 09 Jul 2000 14:46:03 +1000 kaos $"
 
 #include <string.h>
 #include <assert.h>
@@ -258,9 +258,7 @@ obj_relocate (struct obj_file *f, ElfW(Addr) base)
 
   /* Finalize the addresses of the sections.  */
 
-  f->baseaddr = base;
-  for (i = 0; i < n; ++i)
-    f->sections[i]->header.sh_addr += base;
+  arch_finalize_section_address(f, base);
 
   /* And iterate over all of the relocations.  */
 
