@@ -33,6 +33,7 @@ static char *tbtype[] =
 	"usb",
 	"ide",
 	"ieee1394",
+	"kernel",
 	NULL			/* marks the end of the list! */
 };
 
@@ -81,7 +82,7 @@ char *aliaslist[] =
 	"char-major-9 st",
 	"char-major-10 off",		/* was: mouse, was: misc */
 	"char-major-10-0 busmouse",	/* /dev/logibm Logitech bus mouse */
-	"char-major-10-1 psaux",	/* /dev/psaux PS/2-style mouse port */
+	"char-major-10-1 off",		/* /dev/psaux PS/2-style mouse port */
 	"char-major-10-2 msbusmouse",	/* /dev/inportbm Microsoft Inport bus mouse */
 	"char-major-10-3 atixlmouse",	/* /dev/atibm ATI XL bus mouse */
 					/* /dev/jbm J-mouse */
@@ -98,6 +99,8 @@ char *aliaslist[] =
 	"char-major-10-139 openprom",	/* /dev/openprom Linux/Sparc interface */
 	"char-major-10-144 nvram", /* from Tigran Aivazian <tigran@sco.COM> */
 
+	"char-major-10-175 agpgart",    /* /dev/agpgart GART AGP mapping access */
+
 	"char-major-14 soundcore",
 	"char-major-19 cyclades",
 	"char-major-20 cyclades",
@@ -124,6 +127,9 @@ char *aliaslist[] =
 	"iso9660 isofs",
 	"md-personality-1 linear",
 	"md-personality-2 raid0",
+        "md-personality-3 raid1",
+        "md-personality-4 raid5",
+
 	"net-pf-1 unix",	/* PF_UNIX	1  Unix domain sockets */
 	"net-pf-2 ipv4",	/* PF_INET	2  Internet IP Protocol */
 	"net-pf-3 off",		/* PF_AX25	3  Amateur Radio AX.25 */
@@ -153,7 +159,11 @@ char *aliaslist[] =
 	"ppp-compress-24 ppp_deflate",
 	"ppp-compress-26 ppp_deflate",
 
+#ifndef __sparc__
 	"parport_lowlevel parport_pc",
+#else
+        "parport_lowlevel parport_ax",
+#endif
 
 	NULL			/* marks the end of the list! */
 };
