@@ -343,7 +343,7 @@ static int build_list(char **in, OPT_LIST **out, char *version)
  *	Return -1 if any error.
  *	Error messages generated.
  */
-static int do_read(int all, char *force_ver, char *base_dir, char *conf_file)
+static int do_read(int all, char *force_ver, char *base_dir, char *conf_file, int depth)
 {
 	#define MAX_LEVEL 20
 	FILE *fin;
@@ -504,116 +504,125 @@ static int do_read(int all, char *force_ver, char *base_dir, char *conf_file)
 
 	depfile_tmp[0] = '\0';
 
-	maxpath = 100;
-	modpath = (struct PATH_TYPE *)xmalloc(maxpath * sizeof(struct PATH_TYPE));
-	nmodpath = 0;
+	/* Only read the default entries on the first file */
+	if (depth == 0) {
+		maxpath = 100;
+		modpath = (struct PATH_TYPE *)xmalloc(maxpath * sizeof(struct PATH_TYPE));
+		nmodpath = 0;
 
-	maxexecs = 10;
-	execs = (struct EXEC_TYPE *)xmalloc(maxexecs * sizeof(struct EXEC_TYPE));
-	nexecs = 0;
+		maxexecs = 10;
+		execs = (struct EXEC_TYPE *)xmalloc(maxexecs * sizeof(struct EXEC_TYPE));
+		nexecs = 0;
 
-	/*
-	 * Build predef options
-	 */
-	if (all && optlist[0])
-		n_opt_list = build_list(optlist, &opt_list, version);
-
-	/*
-	 * Build predef above
-	 */
-	if (all && above[0])
-		n_abovelist = build_list(above, &abovelist, version);
-
-	/*
-	 * Build predef below
-	 */
-	if (all && below[0])
-		n_belowlist = build_list(below, &belowlist, version);
-
-	/*
-	 * Build predef aliases
-	 */
-	if (all && aliaslist[0])
-		n_aliases = build_list(aliaslist, &aliases, version);
-
-	/*FIXME?: order and priority is now: predefs, MODPATH, modules.conf */
-	if ((envpath = getenv("MODPATH")) != NULL) {
-		size_t len;
-		char *p;
-		char *path;
-
-		/* Make a copy so's we can mung it with strtok.  */
-		len = strlen(envpath) + 1;
-		p = alloca(len);
-		memcpy(p, envpath, len);
-		path = alloca(PATH_MAX);
-
-		for (p = strtok(p, ":"); p != NULL; p = strtok(NULL, ":")) {
-			len = snprintf(path, PATH_MAX, p, version);
-			modpath[nmodpath].path = xstrdup(path);
-			if ((type = strrchr(path, '/')) != NULL)
-				type += 1;
-			else
-				type = "misc";
-			modpath[nmodpath].type = xstrdup(type);
-			if (++nmodpath >= maxpath) {
-				maxpath += 100;
-				modpath = (struct PATH_TYPE *)xrealloc(modpath,
-					maxpath * sizeof(struct PATH_TYPE));
-			}
-
-		}
-	} else {
 		/*
-		 * Build the default "path[type]" configuration
+		 * Build predef options
 		 */
-		int n;
-		char *k;
+		if (all && optlist[0])
+			n_opt_list = build_list(optlist, &opt_list, version);
 
-		/* `uname -r` */
-		sprintf(tmpline, "/lib/modules/%s", version);
-		tbpath[0] = xstrdup(tmpline);
+		/*
+		 * Build predef above
+		 */
+		if (all && above[0])
+			n_abovelist = build_list(above, &abovelist, version);
 
-		/* `kernelversion` */
-		for (n = 0, k = version; *k; ++k) {
-			if (*k == '.' && ++n == 2)
-				break;
-		}
-		sprintf(tmpline, "/lib/modules/%.*s",
-			(/* typecast for Alpha */ int)(k - version), version);
-		tbpath[1] = xstrdup(tmpline);
+		/*
+		 * Build predef below
+		 */
+		if (all && below[0])
+			n_belowlist = build_list(below, &belowlist, version);
 
-		/* The first entry in the path list */
-		modpath[0].type = xstrdup("boot");
-		sprintf(tmpline, "%s/lib/modules/boot", (base_dir?base_dir:""));
-		modpath[0].path = xstrdup(tmpline);
-		nmodpath = 1;
+		/*
+		 * Build predef aliases
+		 */
+		if (all && aliaslist[0])
+			n_aliases = build_list(aliaslist, &aliases, version);
 
-		/* The rest of the entries in the path list */
-		for (pathp = tbpath; *pathp; ++pathp) {
-			char **type;
+		/* Order and priority is now: (MODPATH + modules.conf) || (predefs + modules.conf) */
+		if ((envpath = getenv("MODPATH")) != NULL) {
+			size_t len;
+			char *p;
+			char *path;
 
-			for (type = tbtype; *type; ++type) {
-				char path[100];
+			/* Make a copy so's we can mung it with strtok.  */
+			len = strlen(envpath) + 1;
+			p = alloca(len);
+			memcpy(p, envpath, len);
+			path = alloca(PATH_MAX);
 
-				sprintf(path, "%s%s/%s",
-					(base_dir ? base_dir : ""),
-					*pathp, *type);
-				if (meta_expand(path, &g, NULL, version))
-					return -1;
+			for (p = strtok(p, ":"); p != NULL; p = strtok(NULL, ":")) {
+				len = snprintf(path, PATH_MAX, p, version);
+				modpath[nmodpath].path = xstrdup(path);
+				if ((type = strrchr(path, '/')) != NULL)
+					type += 1;
+				else
+					type = "misc";
+				modpath[nmodpath].type = xstrdup(type);
+				if (++nmodpath >= maxpath) {
+					maxpath += 100;
+					modpath = (struct PATH_TYPE *)xrealloc(modpath,
+						maxpath * sizeof(struct PATH_TYPE));
+				}
 
-				for (glb = g.pathv; glb && *glb; ++glb) {
-					modpath[nmodpath].type = xstrdup(*type);
-					modpath[nmodpath].path = *glb;
-					if (++nmodpath >= maxpath) {
-						maxpath += 100;
-						modpath = (struct PATH_TYPE *)xrealloc(modpath,
-							maxpath * sizeof(struct PATH_TYPE));
+			}
+		} else {
+			/*
+			 * Build the default "path[type]" configuration
+			 */
+			int n;
+			char *k;
+
+			/* `uname -r` */
+			sprintf(tmpline, "/lib/modules/%s", version);
+			tbpath[0] = xstrdup(tmpline);
+
+			/* `kernelversion` */
+			for (n = 0, k = version; *k; ++k) {
+				if (*k == '.' && ++n == 2)
+					break;
+			}
+			sprintf(tmpline, "/lib/modules/%.*s",
+				(/* typecast for Alpha */ int)(k - version), version);
+			tbpath[1] = xstrdup(tmpline);
+
+			/* The first entry in the path list */
+			modpath[0].type = xstrdup("boot");
+			sprintf(tmpline, "%s/lib/modules/boot", (base_dir?base_dir:""));
+			modpath[0].path = xstrdup(tmpline);
+			nmodpath = 1;
+
+			/* The rest of the entries in the path list */
+			for (pathp = tbpath; *pathp; ++pathp) {
+				char **type;
+
+				for (type = tbtype; *type; ++type) {
+					char path[100];
+
+					sprintf(path, "%s%s/%s",
+						(base_dir ? base_dir : ""),
+						*pathp, *type);
+					if (meta_expand(path, &g, NULL, version))
+						return -1;
+
+					for (glb = g.pathv; glb && *glb; ++glb) {
+						modpath[nmodpath].type = xstrdup(*type);
+						modpath[nmodpath].path = *glb;
+						if (++nmodpath >= maxpath) {
+							maxpath += 100;
+							modpath = (struct PATH_TYPE *)xrealloc(modpath,
+								maxpath * sizeof(struct PATH_TYPE));
+						}
 					}
 				}
 			}
 		}
-	}
+
+		/* DEPPATH is intended for testing only */
+		if ((envpath = getenv("DEPPATH")) != NULL) {
+			strncpy(depfile_tmp, envpath, sizeof(depfile_tmp));
+		}
+
+	}	/* End of depth == 0 */
 
 	if (conf_file ||
 	    ((conf_file = getenv("MODULECONFIG")) != NULL && *conf_file)) {
@@ -919,7 +928,7 @@ static int do_read(int all, char *force_ver, char *base_dir, char *conf_file)
 		if (!assgn && strcmp(parm, "include") == 0) {
 			meta_expand(arg, &g, NULL, version);
 
-			if (!do_read(all, version, base_dir, g.pathc ? g.pathv[0] : arg))
+			if (!do_read(all, version, base_dir, g.pathc ? g.pathv[0] : arg, depth+1))
 				one_err = 0;
 			else
 				error("include %s failed\n", arg);
@@ -1226,7 +1235,7 @@ int config_read(int all, char *force_ver, char *base_dir, char *conf_file)
 		return -1;
 	}
 
-	r = do_read(all, force_ver, base_dir, conf_file);
+	r = do_read(all, force_ver, base_dir, conf_file, 0);
 
 	if (quick && !r && !need_update (force_ver, base_dir))
 		exit (0);
@@ -1243,7 +1252,7 @@ static int favail;
 static int one_only;
 static int dirs_only;
 char **list;
-char *looking_for;
+const char *looking_for;
 
 /*
  *	Add a file name if it exist
@@ -1347,7 +1356,7 @@ static int config_add(const char *file, const struct stat *sb, int flag)
  * Return a pointer to the list of modules found (or NULL if error).
  * Update the counter (sent as parameter).
  */
-GLOB_LIST *config_lstmod(char *match, const char *type, int first_only)
+GLOB_LIST *config_lstmod(const char *match, const char *type, int first_only)
 {
 	/*
 	 * Note:
@@ -1432,7 +1441,7 @@ GLOB_LIST *config_lstmod(char *match, const char *type, int first_only)
 }
 
 /* Given a bare module name, poke through the module path to find the file.  */
-char *search_module_path(char *base)
+char *search_module_path(const char *base)
 {
 	GLOB_LIST *g;
 
@@ -1445,6 +1454,12 @@ char *search_module_path(char *base)
 
 		sprintf(base_o, "%s.o", base);
 		g = config_lstmod(base_o, NULL, 1);
+#ifdef CONFIG_USE_ZLIB
+		if (g == NULL || g->pathc == 0) {
+			sprintf(base_o, "%s.o.gz", base);
+			g = config_lstmod(base_o, NULL, 1);
+		}
+#endif
 	}
 	if (g == NULL || g->pathc == 0)
 		return NULL;
